@@ -18,15 +18,16 @@
 """Classes for geometry operations"""
 
 from logging import getLogger
-import warnings
 import numpy as np
+import pyproj
+import warnings
 
 try:
     from xarray import DataArray
 except ImportError:
     DataArray = np.ndarray
 
-from pyresample.utils import proj4_str_to_dict
+from pyresample.utils._proj4 import proj4_str_to_dict
 import cartopy.crs as ccrs
 import shapely.geometry as sgeom
 
@@ -60,6 +61,9 @@ def _globe_from_proj4(proj4_terms):
 class _PROJ4Projection(ccrs.Projection):
 
     def __init__(self, proj4_terms, globe=None, bounds=None):
+        if 'EPSG' in proj4_terms.upper():
+            warnings.warn('Converting EPSG projection to proj4 string, which is a potentially lossy transformation')
+            proj4_terms = pyproj.Proj(proj4_terms).definition_string().strip()
         terms = proj4_str_to_dict(proj4_terms)
         globe = _globe_from_proj4(terms) if globe is None else globe
 
@@ -93,7 +97,7 @@ class _PROJ4Projection(ccrs.Projection):
     @property
     def threshold(self):
         x0, x1, y0, y1 = self.bounds
-        return min(x1 - x0, y1 - y0) / 100.
+        return min(abs(x1 - x0), abs(y1 - y0)) / 100.
 
 
 def _lesser_from_proj(proj4_terms, globe=None, bounds=None):
