@@ -430,7 +430,7 @@ def _get_valid_input_index(source_geo_def,
                     source_lons, source_lats,
                     radius_of_influence)
 
-    if (isinstance(valid_input_index, np.ma.core.MaskedArray)):
+    if isinstance(valid_input_index, np.ma.core.MaskedArray):
         # Make sure valid_input_index is not a masked array
         valid_input_index = valid_input_index.filled(False)
 
@@ -964,7 +964,7 @@ class XArrayResamplerNN(object):
     def __init__(self,
                  source_geo_def,
                  target_geo_def,
-                 radius_of_influence,
+                 radius_of_influence=None,
                  neighbours=1,
                  epsilon=0):
         """
@@ -975,8 +975,10 @@ class XArrayResamplerNN(object):
             Geometry definition of source
         target_geo_def : object
             Geometry definition of target
-        radius_of_influence : float
-            Cut off distance in meters
+        radius_of_influence : float, optional
+            Cut off distance in geocentric meters.
+            If not provided this will be estimated based on the source
+            and target geometry definition.
         neighbours : int, optional
             The number of neigbours to consider for each grid point.
             Default 1. Currently 1 is the only supported number.
@@ -997,13 +999,36 @@ class XArrayResamplerNN(object):
         self.epsilon = epsilon
         self.source_geo_def = source_geo_def
         self.target_geo_def = target_geo_def
+        if radius_of_influence is None:
+            radius_of_influence = self._compute_radius_of_influence()
         self.radius_of_influence = radius_of_influence
         assert (self.target_geo_def.ndim == 2), \
             "Target area definition must be 2 dimensions"
 
+    def _compute_radius_of_influence(self):
+        """Estimate a good default radius_of_influence."""
+        try:
+            src_res = self.source_geo_def.geocentric_resolution()
+        except RuntimeError:
+            logger.warning("Could not calculate source definition resolution")
+            src_res = np.nan
+        try:
+            dst_res = self.target_geo_def.geocentric_resolution()
+        except RuntimeError:
+            logger.warning("Could not calculate destination definition "
+                           "resolution")
+            dst_res = np.nan
+        radius_of_influence = np.nanmax([src_res, dst_res])
+        if np.isnan(radius_of_influence):
+            logger.warning("Could not calculate radius_of_influence, falling "
+                           "back to 10000 meters. This may produce lower "
+                           "quality results than expected.")
+            radius_of_influence = 10000
+        return radius_of_influence
+
     def _create_resample_kdtree(self, chunks=CHUNK_SIZE):
         """Set up kd tree on input"""
-        source_lons, source_lats = self.source_geo_def.get_lonlats_dask(
+        source_lons, source_lats = self.source_geo_def.get_lonlats(
             chunks=chunks)
         valid_input_idx = ((source_lons >= -180) & (source_lons <= 180) &
                            (source_lats <= 90) & (source_lats >= -90))
@@ -1058,7 +1083,8 @@ class XArrayResamplerNN(object):
         self.valid_input_index = valid_input_idx
         self.delayed_kdtree = resample_kdtree
 
-        target_lons, target_lats = self.target_geo_def.get_lonlats_dask()
+        # TODO: Add 'chunks' keyword argument to this method and use it
+        target_lons, target_lats = self.target_geo_def.get_lonlats(chunks=CHUNK_SIZE)
         valid_output_idx = ((target_lons >= -180) & (target_lons <= 180) &
                             (target_lats <= 90) & (target_lats >= -90))
 
@@ -1094,7 +1120,7 @@ class XArrayResamplerNN(object):
         and/or pykdtree.
 
         Args:
-            data (dask.array.Array): Source data pixels to sample
+            data (xarray.DataArray): Source data pixels to sample
             fill_value (float): Output fill value when no source data is
                 near the target pixel. When omitted, if the input data is an
                 integer array then the maximum value for that integer type is
@@ -1147,7 +1173,8 @@ class XArrayResamplerNN(object):
         coords = {c: c_var for c, c_var in data.coords.items()
                   if not contain_coords(c_var, src_geo_dims + dst_geo_dims)}
         try:
-            coord_x, coord_y = self.target_geo_def.get_proj_vectors_dask()
+            # TODO: Add 'chunks' kwarg
+            coord_x, coord_y = self.target_geo_def.get_proj_vectors(chunks=CHUNK_SIZE)
             coords['y'] = coord_y
             coords['x'] = coord_x
         except AttributeError:
