@@ -201,8 +201,12 @@ class Test(unittest.TestCase):
             lat, 52.566998432390619, msg='Resampling of single lat failed')
 
     def test_proj4_string(self):
+        """Test 'proj_str' property of AreaDefinition."""
+        from pyresample.utils import is_pyproj2
         proj4_string = self.area_def.proj_str
         expected_string = '+a=6378144.0 +b=6356759.0 +lat_ts=50.0 +lon_0=8.0 +proj=stere +lat_0=50.0'
+        if is_pyproj2():
+            expected_string += ' +type=crs'
         self.assertEqual(
             frozenset(proj4_string.split()), frozenset(expected_string.split()))
 
