@@ -71,8 +71,7 @@ class Test(unittest.TestCase):
         res = area_con.image_data
         cross_sum = res.sum()
         expected = 399936.39392500359
-        self.assertAlmostEqual(
-            cross_sum, expected, msg='ImageContainer resampling quick failed')
+        self.assertAlmostEqual(cross_sum, expected)
 
     @tmp
     def test_image_segments(self):
@@ -82,16 +81,14 @@ class Test(unittest.TestCase):
         res = area_con.image_data
         cross_sum = res.sum()
         expected = 399936.39392500359
-        self.assertAlmostEqual(
-            cross_sum, expected, msg='ImageContainer resampling quick segments failed')
+        self.assertAlmostEqual(cross_sum, expected)
 
     def test_return_type(self):
         data = numpy.ones((3712, 3712)).astype('int')
         msg_con = image.ImageContainerQuick(data, self.msg_area, segments=1)
         area_con = msg_con.resample(self.area_def)
         res = area_con.image_data
-        self.assertTrue(
-            data.dtype is res.dtype, msg='Failed to maintain input data type')
+        self.assertTrue(data.dtype is res.dtype)
 
     @mask
     def test_masked_image(self):
@@ -107,8 +104,7 @@ class Test(unittest.TestCase):
         expected = numpy.fromfile(os.path.join(os.path.dirname(__file__),
                                                'test_files', 'mask_grid.dat'),
                                   sep=' ').reshape((800, 800))
-        self.assertTrue(numpy.array_equal(
-            resampled_mask, expected), msg='Failed to resample masked array')
+        self.assertTrue(numpy.array_equal(resampled_mask, expected))
 
     @mask
     def test_masked_image_fill(self):
@@ -125,8 +121,7 @@ class Test(unittest.TestCase):
                                                'test_files',
                                                'mask_grid.dat'),
                                   sep=' ').reshape((800, 800))
-        self.assertTrue(numpy.array_equal(
-            resampled_mask, expected), msg='Failed to resample masked array')
+        self.assertTrue(numpy.array_equal(resampled_mask, expected))
 
     def test_nearest_neighbour(self):
         data = numpy.fromfunction(lambda y, x: y * x * 10 ** -6, (3712, 3712))
@@ -135,9 +130,8 @@ class Test(unittest.TestCase):
         area_con = msg_con.resample(self.area_def)
         res = area_con.image_data
         cross_sum = res.sum()
-        expected = 399936.783062
-        self.assertAlmostEqual(cross_sum, expected,
-                               msg='ImageContainer resampling nearest neighbour failed')
+        expected = 399936.70287099993
+        self.assertAlmostEqual(cross_sum, expected)
 
     def test_nearest_resize(self):
         data = numpy.fromfunction(lambda y, x: y * x * 10 ** -6, (3712, 3712))
@@ -147,8 +141,7 @@ class Test(unittest.TestCase):
         res = area_con.image_data
         cross_sum = res.sum()
         expected = 2212023.0175830
-        self.assertAlmostEqual(cross_sum, expected,
-                               msg='ImageContainer resampling nearest neighbour failed')
+        self.assertAlmostEqual(cross_sum, expected)
 
     def test_nearest_neighbour_multi(self):
         data1 = numpy.fromfunction(lambda y, x: y * x * 10 ** -6, (3712, 3712))
@@ -160,13 +153,12 @@ class Test(unittest.TestCase):
         area_con = msg_con.resample(self.area_def)
         res = area_con.image_data
         cross_sum1 = res[:, :, 0].sum()
-        expected1 = 399936.783062
-        self.assertAlmostEqual(cross_sum1, expected1,
-                               msg='ImageContainer resampling nearest neighbour multi failed')
+        expected1 = 399936.70287099993
+        self.assertAlmostEqual(cross_sum1, expected1)
+
         cross_sum2 = res[:, :, 1].sum()
-        expected2 = 399936.783062 * 2
-        self.assertAlmostEqual(cross_sum2, expected2,
-                               msg='ImageContainer resampling nearest neighbour multi failed')
+        expected2 = 399936.70287099993 * 2
+        self.assertAlmostEqual(cross_sum2, expected2)
 
     def test_nearest_neighbour_multi_preproc(self):
         data1 = numpy.fromfunction(lambda y, x: y * x * 10 ** -6, (3712, 3712))
@@ -182,13 +174,12 @@ class Test(unittest.TestCase):
                                                                50000)
         res = msg_con.get_array_from_linesample(row_indices, col_indices)
         cross_sum1 = res[:, :, 0].sum()
-        expected1 = 399936.783062
-        self.assertAlmostEqual(cross_sum1, expected1,
-                               msg='ImageContainer resampling nearest neighbour multi preproc failed')
+        expected1 = 399936.70287099993
+        self.assertAlmostEqual(cross_sum1, expected1)
+
         cross_sum2 = res[:, :, 1].sum()
-        expected2 = 399936.783062 * 2
-        self.assertAlmostEqual(cross_sum2, expected2,
-                               msg='ImageContainer resampling nearest neighbour multi preproc failed')
+        expected2 = 399936.70287099993 * 2
+        self.assertAlmostEqual(cross_sum2, expected2)
 
     def test_nearest_swath(self):
         data = numpy.fromfunction(lambda y, x: y * x, (50, 10))
@@ -201,8 +192,7 @@ class Test(unittest.TestCase):
         res = area_con.image_data
         cross_sum = res.sum()
         expected = 15874591.0
-        self.assertEqual(cross_sum, expected,
-                         msg='ImageContainer swath resampling nearest failed')
+        self.assertEqual(cross_sum, expected)
 
     def test_nearest_swath_segments(self):
         data = numpy.fromfunction(lambda y, x: y * x, (50, 10))
@@ -216,8 +206,7 @@ class Test(unittest.TestCase):
         res = area_con.image_data
         cross_sum = res.sum()
         expected = 3 * 15874591.0
-        self.assertEqual(cross_sum, expected,
-                         msg='ImageContainer swath segments resampling nearest failed')
+        self.assertEqual(cross_sum, expected)
 
     def test_bilinear(self):
         data = numpy.fromfunction(lambda y, x: y * x * 10 ** -6, (928, 928))
@@ -227,7 +216,7 @@ class Test(unittest.TestCase):
         area_con = msg_con.resample(self.area_def)
         res = area_con.image_data
         cross_sum = res.sum()
-        expected = 24690.127073654239
+        expected = 24712.589910252744
         self.assertAlmostEqual(cross_sum, expected)
 
     def test_bilinear_multi(self):
@@ -241,10 +230,10 @@ class Test(unittest.TestCase):
         area_con = msg_con.resample(self.area_def)
         res = area_con.image_data
         cross_sum1 = res[:, :, 0].sum()
-        expected1 = 24690.127073654239
+        expected1 = 24712.589910252744
         self.assertAlmostEqual(cross_sum1, expected1)
         cross_sum2 = res[:, :, 1].sum()
-        expected2 = 24690.127073654239 * 2
+        expected2 = 24712.589910252744 * 2
         self.assertAlmostEqual(cross_sum2, expected2)
 
     def test_bilinear_swath(self):
@@ -257,7 +246,7 @@ class Test(unittest.TestCase):
         area_con = swath_con.resample(self.area_def)
         res = area_con.image_data
         cross_sum = res.sum()
-        expected = 16762584.12441789
+        expected = 16852120.789503865
         self.assertAlmostEqual(cross_sum, expected)
 
 
