@@ -9,10 +9,13 @@ import numpy as np
 from pyresample import geometry, kd_tree, utils
 from pyresample.test.utils import catch_warnings
 
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
+
+try:
+    from unittest import mock
+except ImportError:
+    # python 2.7
+    import mock
 
 
 class Test(unittest.TestCase):
@@ -49,7 +52,7 @@ class Test(unittest.TestCase):
         self.assertTrue(res[0] == 2)
 
     def test_gauss_base(self):
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res = kd_tree.resample_gauss(self.tswath,
                                          self.tdata.ravel(), self.tgrid,
                                          50000, 25000, reduce_data=False, segments=1)
@@ -61,7 +64,7 @@ class Test(unittest.TestCase):
         def wf(dist):
             return 1 - dist / 100000.0
 
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res = kd_tree.resample_custom(self.tswath,
                                           self.tdata.ravel(), self.tgrid,
                                           50000, wf, reduce_data=False, segments=1)
@@ -71,7 +74,7 @@ class Test(unittest.TestCase):
 
     def test_gauss_uncert(self):
         sigma = utils.fwhm2sigma(41627.730557884883)
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res, stddev, count = kd_tree.resample_gauss(self.tswath, self.tdata,
                                                         self.tgrid, 100000, sigma,
                                                         with_uncert=True)
@@ -89,7 +92,7 @@ class Test(unittest.TestCase):
         def wf(dist):
             return 1 - dist / 100000.0
 
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res, stddev, counts = kd_tree.resample_custom(self.tswath,
                                                           self.tdata, self.tgrid,
                                                           100000, wf, with_uncert=True)
@@ -266,7 +269,7 @@ class Test(unittest.TestCase):
         lats = np.fromfunction(
             lambda y, x: 75 - (50.0 / 5000) * y, (5000, 100))
         swath_def = geometry.SwathDefinition(lons=lons, lats=lats)
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res = kd_tree.resample_gauss(swath_def, data.ravel(),
                                          self.area_def, 50000, 25000, segments=1)
             self.assertFalse(len(w) != 1)
@@ -282,7 +285,7 @@ class Test(unittest.TestCase):
         lats = np.fromfunction(
             lambda y, x: 75 - (50.0 / 5000) * y, (5000, 100))
         swath_def = geometry.SwathDefinition(lons=lons, lats=lats)
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res = kd_tree.resample_gauss(swath_def, data.ravel(),
                                          self.area_def, 50000, utils.fwhm2sigma(41627.730557884883), segments=1)
             self.assertFalse(len(w) != 1)
@@ -300,7 +303,7 @@ class Test(unittest.TestCase):
         swath_def = geometry.SwathDefinition(lons=lons, lats=lats)
         data_multi = np.column_stack((data.ravel(), data.ravel(),
                                       data.ravel()))
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res = kd_tree.resample_gauss(swath_def, data_multi,
                                          self.area_def, 50000, [25000, 15000, 10000], segments=1)
             self.assertFalse(len(w) != 1)
@@ -318,7 +321,7 @@ class Test(unittest.TestCase):
         swath_def = geometry.SwathDefinition(lons=lons, lats=lats)
         data_multi = np.column_stack((data.ravel(), data.ravel(),
                                       data.ravel()))
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             # The assertion below checks if there is only one warning raised
             # and whether it contains a specific message from pyresample
             # On python 2.7.9+ the resample_gauss method raises multiple deprecation warnings
@@ -354,7 +357,7 @@ class Test(unittest.TestCase):
         swath_def = geometry.SwathDefinition(lons=lons, lats=lats)
         data_multi = np.column_stack((data.ravel(), data.ravel(),
                                       data.ravel()))
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res = kd_tree.resample_gauss(swath_def, data_multi,
                                          self.area_def, 50000, [
                                              25000, 15000, 10000],
@@ -374,7 +377,7 @@ class Test(unittest.TestCase):
         swath_def = geometry.SwathDefinition(lons=lons, lats=lats)
         data_multi = np.column_stack((data.ravel(), data.ravel(),
                                       data.ravel()))
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res = kd_tree.resample_gauss(swath_def, data_multi,
                                          self.area_def, 50000, [
                                              25000, 15000, 10000],
@@ -411,11 +414,25 @@ class Test(unittest.TestCase):
         lats = np.fromfunction(
             lambda y, x: 75 - (50.0 / 5000) * y, (5000, 100))
         swath_def = geometry.SwathDefinition(lons=lons, lats=lats)
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res = kd_tree.resample_custom(swath_def, data.ravel(),
                                           self.area_def, 50000, wf, segments=1)
-            self.assertFalse(len(w) != 1)
-            self.assertFalse(('Possible more' not in str(w[0].message)))
+            # PyProj proj/CRS and "more than 8 neighbours" are warned about
+            self.assertFalse(len(w) > 2)
+            neighbour_warn = False
+            for warn in w:
+                if 'Possible more' in str(warn.message):
+                    neighbour_warn = True
+                    break
+            self.assertTrue(neighbour_warn)
+            if len(w) == 2:
+                proj_crs_warn = False
+                for warn in w:
+                    if 'important projection information' in str(warn.message):
+                        proj_crs_warn = True
+                        break
+                self.assertTrue(proj_crs_warn)
+
         cross_sum = res.sum()
         expected = 4872.8100347930776
         self.assertAlmostEqual(cross_sum, expected)
@@ -438,7 +455,7 @@ class Test(unittest.TestCase):
         swath_def = geometry.SwathDefinition(lons=lons, lats=lats)
         data_multi = np.column_stack((data.ravel(), data.ravel(),
                                       data.ravel()))
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             res = kd_tree.resample_custom(swath_def, data_multi,
                                           self.area_def, 50000, [wf1, wf2, wf3], segments=1)
             self.assertFalse(len(w) != 1)
@@ -633,7 +650,7 @@ class Test(unittest.TestCase):
         data_multi = np.column_stack((data.ravel(), data.ravel(),
                                       data.ravel()))
 
-        with catch_warnings() as w:
+        with catch_warnings(UserWarning) as w:
             valid_input_index, valid_output_index, index_array, distance_array = \
                 kd_tree.get_neighbour_info(swath_def,
                                            self.area_def,
@@ -873,6 +890,47 @@ class TestXArrayResamplerNN(unittest.TestCase):
         expected = 27706753.0
         self.assertEqual(cross_sum, expected)
 
+    def test_nearest_area_2d_to_area_1n_no_roi(self):
+        """Test 2D area definition to 2D area definition; 1 neighbor, no radius of influence."""
+        from pyresample.kd_tree import XArrayResamplerNN
+        import xarray as xr
+        import dask.array as da
+        data = self.data_2d
+        resampler = XArrayResamplerNN(self.src_area_2d, self.area_def,
+                                      neighbours=1)
+        ninfo = resampler.get_neighbour_info()
+        for val in ninfo[:3]:
+            # vii, ia, voi
+            self.assertIsInstance(val, da.Array)
+        self.assertRaises(AssertionError,
+                          resampler.get_sample_from_neighbour_info, data)
+
+        # rename data dimensions to match the expected area dimensions
+        data = data.rename({'my_dim_y': 'y', 'my_dim_x': 'x'})
+        res = resampler.get_sample_from_neighbour_info(data)
+        self.assertIsInstance(res, xr.DataArray)
+        self.assertIsInstance(res.data, da.Array)
+        res = res.values
+        cross_sum = np.nansum(res)
+        expected = 32114793.0
+        self.assertEqual(cross_sum, expected)
+
+        # pretend the resolutions can't be determined
+        with mock.patch.object(self.src_area_2d, 'geocentric_resolution') as sgr, \
+                mock.patch.object(self.area_def, 'geocentric_resolution') as dgr:
+            sgr.side_effect = RuntimeError
+            dgr.side_effect = RuntimeError
+            resampler = XArrayResamplerNN(self.src_area_2d, self.area_def,
+                                          neighbours=1)
+            resampler.get_neighbour_info()
+            res = resampler.get_sample_from_neighbour_info(data)
+            self.assertIsInstance(res, xr.DataArray)
+            self.assertIsInstance(res.data, da.Array)
+            res = res.values
+            cross_sum = np.nansum(res)
+            expected = 1855928.0
+            self.assertEqual(cross_sum, expected)
+
     def test_nearest_area_2d_to_area_1n_3d_data(self):
         """Test 2D area definition to 2D area definition; 1 neighbor, 3d data."""
         from pyresample.kd_tree import XArrayResamplerNN
