@@ -37,7 +37,7 @@ class TestSCoordinate(unittest.TestCase):
         """Test Vincenty formula
         """
         d = SCoordinate(0, 0).distance(SCoordinate(1, 1))
-        self.assertEquals(d, 1.2745557823062943)
+        self.assertEqual(d, 1.2745557823062943)
 
     def test_hdistance(self):
         """Test Haversine formula
@@ -185,7 +185,7 @@ class TestArc(unittest.TestCase):
         lon, lat = arc1.intersection(arc2)
 
         self.assertTrue(np.allclose(np.rad2deg(lon), 5))
-        self.assertEquals(np.rad2deg(lat).round(7), round(5.0575148968282093, 7))
+        self.assertEqual(np.rad2deg(lat).round(7), round(5.0575148968282093, 7))
 
         arc1 = Arc(SCoordinate(0, 0),
                    SCoordinate(np.deg2rad(10), np.deg2rad(10)))
@@ -202,7 +202,7 @@ class TestArc(unittest.TestCase):
                                np.deg2rad(50.935830837274324)))
         inter = SCoordinate(np.deg2rad(20.165957021925202),
                             np.deg2rad(46.177022633103398))
-        self.assertEquals(arc1.intersection(arc2), inter)
+        self.assertEqual(arc1.intersection(arc2), inter)
 
         arc1 = Arc(SCoordinate(np.deg2rad(-2.4982818108326734),
                                np.deg2rad(48.596644847869655)),
@@ -556,6 +556,16 @@ class TestSphericalPolygon(unittest.TestCase):
         self.assertTrue(np.allclose(poly_inter.vertices,
                                     np.deg2rad(res)))
 
+    def test_consistent_radius(self):
+        poly1 = np.array([(-50, 69), (-36, 69), (-36, 64), (-50, 64)])
+        poly2 = np.array([(-46, 68), (-40, 68), (-40, 65), (-45, 65)])
+        poly_outer = SphPolygon(np.deg2rad(poly1), radius=6371)
+        poly_inner = SphPolygon(np.deg2rad(poly2), radius=6371)
+        poly_inter = poly_outer.intersection(poly_inner)
+        self.assertAlmostEqual(poly_inter.radius, poly_inner.radius)
+        # Well, now when we are at it.
+        self.assertAlmostEqual(poly_inter.area(), poly_inner.area())
+
 
 def suite():
     """The suite for test_spherical
