@@ -7,13 +7,13 @@ import warnings
 warnings.simplefilter("always")
 
 import numpy as np
-
+from pyresample.test.utils import catch_warnings
 from pyresample import kd_tree, geometry
 
-
-def tmp(f):
-    f.tmp = True
-    return f
+if sys.version_info < (2, 7):
+    import unittest2 as unittest
+else:
+    import unittest
 
 
 class Test(unittest.TestCase):
@@ -32,20 +32,15 @@ class Test(unittest.TestCase):
     lats = lats[valid_fov]
     tb37v = tb37v[valid_fov]
 
-    @tmp
     def test_self_map(self):
         swath_def = geometry.SwathDefinition(lons=self.lons, lats=self.lats)
-        if sys.version_info < (2, 6):
+        with catch_warnings() as w:
             res = kd_tree.resample_gauss(swath_def, self.tb37v.copy(), swath_def,
                                          radius_of_influence=70000, sigmas=56500)
-        else:
-            with warnings.catch_warnings(record=True) as w:
-                res = kd_tree.resample_gauss(swath_def, self.tb37v.copy(), swath_def,
-                                             radius_of_influence=70000, sigmas=56500)
-                self.assertFalse(
-                    len(w) != 1, 'Failed to create neighbour radius warning')
-                self.assertFalse(('Possible more' not in str(
-                    w[0].message)), 'Failed to create correct neighbour radius warning')
+            self.assertFalse(
+                len(w) != 1, 'Failed to create neighbour radius warning')
+            self.assertFalse(('Possible more' not in str(
+                w[0].message)), 'Failed to create correct neighbour radius warning')
 
         if sys.platform == 'darwin':
             # OSX seems to get slightly different results for `_spatial_mp.Cartesian`
@@ -59,18 +54,13 @@ class Test(unittest.TestCase):
         data = np.column_stack((self.tb37v, self.tb37v, self.tb37v))
         swath_def = geometry.SwathDefinition(lons=self.lons, lats=self.lats)
 
-        if (sys.version_info < (2, 6) or
-                (sys.version_info >= (3, 0) and sys.version_info < (3, 4))):
+        with catch_warnings() as w:
             res = kd_tree.resample_gauss(swath_def, data, swath_def,
                                          radius_of_influence=70000, sigmas=[56500, 56500, 56500])
-        else:
-            with warnings.catch_warnings(record=True) as w:
-                res = kd_tree.resample_gauss(swath_def, data, swath_def,
-                                             radius_of_influence=70000, sigmas=[56500, 56500, 56500])
-                self.assertFalse(
-                    len(w) != 1, 'Failed to create neighbour radius warning')
-                self.assertFalse(('Possible more' not in str(
-                    w[0].message)), 'Failed to create correct neighbour radius warning')
+            self.assertFalse(
+                len(w) != 1, 'Failed to create neighbour radius warning')
+            self.assertFalse(('Possible more' not in str(
+                w[0].message)), 'Failed to create correct neighbour radius warning')
 
         if sys.platform == 'darwin':
             # OSX seems to get slightly different results for `_spatial_mp.Cartesian`
