@@ -107,7 +107,7 @@ def treat_deprecations_as_exceptions():
         warnings.filterwarnings(
             "ignore",
             r"This module will be removed in pyresample 2\.0\, please use the"
-            r"\`pyresample.spherical\` module functions and classe instead\.",
+            r"\`pyresample.spherical\` module functions and class instead\.",
             DeprecationWarning)
 
     if sys.version_info[:2] >= (3, 5):
@@ -178,3 +178,21 @@ def create_test_latitude(start, stop, shape, twist_factor=0.0, dtype=np.float32)
     lat_array = np.repeat(lat_col, shape[1], axis=1)
     lat_array += twist_array
     return lat_array
+
+
+class CustomScheduler(object):
+    """Scheduler raising an exception if data are computed too many times."""
+
+    def __init__(self, max_computes=1):
+        """Set starting and maximum compute counts."""
+        self.max_computes = max_computes
+        self.total_computes = 0
+
+    def __call__(self, dsk, keys, **kwargs):
+        """Compute dask task and keep track of number of times we do so."""
+        import dask
+        self.total_computes += 1
+        if self.total_computes > self.max_computes:
+            raise RuntimeError("Too many dask computations were scheduled: "
+                               "{}".format(self.total_computes))
+        return dask.get(dsk, keys, **kwargs)
